==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DevicePolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DevicePolicyRuleConditionPlatform;
import com.okta.sdk.resource.model.DevicePolicyTrustLevel;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DevicePolicyRuleCondition
 */
@JsonPropertyOrder({ DevicePolicyRuleCondition.JSON_PROPERTY_MIGRATED, DevicePolicyRuleCondition.JSON_PROPERTY_PLATFORM,
        DevicePolicyRuleCondition.JSON_PROPERTY_ROOTED, DevicePolicyRuleCondition.JSON_PROPERTY_TRUST_LEVEL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class DevicePolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MIGRATED = "migrated";
    private Boolean migrated;

    public static final String JSON_PROPERTY_PLATFORM = "platform";
    private DevicePolicyRuleConditionPlatform platform;

    public static final String JSON_PROPERTY_ROOTED = "rooted";
    private Boolean rooted;

    public static final String JSON_PROPERTY_TRUST_LEVEL = "trustLevel";
    private DevicePolicyTrustLevel trustLevel;

    public DevicePolicyRuleCondition() {
    }

    public DevicePolicyRuleCondition migrated(Boolean migrated) {

        this.migrated = migrated;
        return this;
    }

    /**
     * Get migrated
     *
     * @return migrated
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MIGRATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getMigrated() {
        return migrated;
    }

    @JsonProperty(JSON_PROPERTY_MIGRATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMigrated(Boolean migrated) {
        this.migrated = migrated;
    }

    public DevicePolicyRuleCondition platform(DevicePolicyRuleConditionPlatform platform) {

        this.platform = platform;
        return this;
    }

    /**
     * Get platform
     *
     * @return platform
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DevicePolicyRuleConditionPlatform getPlatform() {
        return platform;
    }

    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPlatform(DevicePolicyRuleConditionPlatform platform) {
        this.platform = platform;
    }

    public DevicePolicyRuleCondition rooted(Boolean rooted) {

        this.rooted = rooted;
        return this;
    }

    /**
     * Get rooted
     *
     * @return rooted
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ROOTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getRooted() {
        return rooted;
    }

    @JsonProperty(JSON_PROPERTY_ROOTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRooted(Boolean rooted) {
        this.rooted = rooted;
    }

    public DevicePolicyRuleCondition trustLevel(DevicePolicyTrustLevel trustLevel) {

        this.trustLevel = trustLevel;
        return this;
    }

    /**
     * Get trustLevel
     *
     * @return trustLevel
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TRUST_LEVEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DevicePolicyTrustLevel getTrustLevel() {
        return trustLevel;
    }

    @JsonProperty(JSON_PROPERTY_TRUST_LEVEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTrustLevel(DevicePolicyTrustLevel trustLevel) {
        this.trustLevel = trustLevel;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DevicePolicyRuleCondition devicePolicyRuleCondition = (DevicePolicyRuleCondition) o;
        return Objects.equals(this.migrated, devicePolicyRuleCondition.migrated)
                && Objects.equals(this.platform, devicePolicyRuleCondition.platform)
                && Objects.equals(this.rooted, devicePolicyRuleCondition.rooted)
                && Objects.equals(this.trustLevel, devicePolicyRuleCondition.trustLevel);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(migrated, platform, rooted, trustLevel);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DevicePolicyRuleCondition {\n");
        sb.append("    migrated: ").append(toIndentedString(migrated)).append("\n");
        sb.append("    platform: ").append(toIndentedString(platform)).append("\n");
        sb.append("    rooted: ").append(toIndentedString(rooted)).append("\n");
        sb.append("    trustLevel: ").append(toIndentedString(trustLevel)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-23.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/DevicePolicyRuleCondition.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.DevicePolicyRuleConditionPlatform;
import com.okta.sdk.resource.model.DevicePolicyTrustLevel;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * DevicePolicyRuleCondition
 */
@JsonPropertyOrder({ DevicePolicyRuleCondition.JSON_PROPERTY_MIGRATED, DevicePolicyRuleCondition.JSON_PROPERTY_PLATFORM,
        DevicePolicyRuleCondition.JSON_PROPERTY_ROOTED, DevicePolicyRuleCondition.JSON_PROPERTY_TRUST_LEVEL })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-05-05T16:46:15.395194+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class DevicePolicyRuleCondition implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_MIGRATED = "migrated";
    private Boolean migrated;

    public static final String JSON_PROPERTY_PLATFORM = "platform";
    private DevicePolicyRuleConditionPlatform platform;

    public static final String JSON_PROPERTY_ROOTED = "rooted";
    private Boolean rooted;

    public static final String JSON_PROPERTY_TRUST_LEVEL = "trustLevel";
    private DevicePolicyTrustLevel trustLevel;

    public DevicePolicyRuleCondition() {
    }

    public DevicePolicyRuleCondition migrated(Boolean migrated) {

        this.migrated = migrated;
        return this;
    }

    /**
     * Get migrated
     *
     * @return migrated
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_MIGRATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getMigrated() {
        return migrated;
    }

    @JsonProperty(JSON_PROPERTY_MIGRATED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setMigrated(Boolean migrated) {
        this.migrated = migrated;
    }

    public DevicePolicyRuleCondition platform(DevicePolicyRuleConditionPlatform platform) {

        this.platform = platform;
        return this;
    }

    /**
     * Get platform
     *
     * @return platform
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DevicePolicyRuleConditionPlatform getPlatform() {
        return platform;
    }

    @JsonProperty(JSON_PROPERTY_PLATFORM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setPlatform(DevicePolicyRuleConditionPlatform platform) {
        this.platform = platform;
    }

    public DevicePolicyRuleCondition rooted(Boolean rooted) {

        this.rooted = rooted;
        return this;
    }

    /**
     * Get rooted
     *
     * @return rooted
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ROOTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public Boolean getRooted() {
        return rooted;
    }

    @JsonProperty(JSON_PROPERTY_ROOTED)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setRooted(Boolean rooted) {
        this.rooted = rooted;
    }

    public DevicePolicyRuleCondition trustLevel(DevicePolicyTrustLevel trustLevel) {

        this.trustLevel = trustLevel;
        return this;
    }

    /**
     * Get trustLevel
     *
     * @return trustLevel
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TRUST_LEVEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public DevicePolicyTrustLevel getTrustLevel() {
        return trustLevel;
    }

    @JsonProperty(JSON_PROPERTY_TRUST_LEVEL)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setTrustLevel(DevicePolicyTrustLevel trustLevel) {
        this.trustLevel = trustLevel;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        DevicePolicyRuleCondition devicePolicyRuleCondition = (DevicePolicyRuleCondition) o;
        return Objects.equals(this.migrated, devicePolicyRuleCondition.migrated)
                && Objects.equals(this.platform, devicePolicyRuleCondition.platform)
                && Objects.equals(this.rooted, devicePolicyRuleCondition.rooted)
                && Objects.equals(this.trustLevel, devicePolicyRuleCondition.trustLevel);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(migrated, platform, rooted, trustLevel);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class DevicePolicyRuleCondition {\n");
        sb.append("    migrated: ").append(toIndentedString(migrated)).append("\n");
        sb.append("    platform: ").append(toIndentedString(platform)).append("\n");
        sb.append("    rooted: ").append(toIndentedString(rooted)).append("\n");
        sb.append("    trustLevel: ").append(toIndentedString(trustLevel)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
